<?php

namespace Litecms\Adds\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Adds\Interfaces\AddsRepositoryInterface;

class AddsPublicController extends BaseController
{
    // use AddsWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Adds\Interfaces\AddsRepositoryInterface $adds
     *
     * @return type
     */
    public function __construct(AddsRepositoryInterface $adds)
    {
        $this->repository = $adds;
        parent::__construct();
    }

    /**
     * Show adds's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $adds = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$adds::$adds.names'))
            ->view('$adds::public.adds.index')
            ->data(compact('$adds'))
            ->output();
    }

    /**
     * Show adds's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $adds = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$adds::$adds.names'))
            ->view('$adds::public.adds.index')
            ->data(compact('$adds'))
            ->output();
    }

    /**
     * Show adds.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $adds = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$adds->name . trans('$adds::$adds.name'))
            ->view('$adds::public.adds.show')
            ->data(compact('$adds'))
            ->output();
    }

}
