<?php

namespace Litecms\Adds\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Adds\Models\Adds;

class AddsPolicy
{

    /**
     * Determine if the given user can view the adds.
     *
     * @param UserPolicy $user
     * @param Adds $adds
     *
     * @return bool
     */
    public function view(UserPolicy $user, Adds $adds)
    {
        if ($user->canDo('adds.adds.view') && $user->isAdmin()) {
            return true;
        }

        return $adds->user_id == user_id() && $adds->user_type == user_type();
    }

    /**
     * Determine if the given user can create a adds.
     *
     * @param UserPolicy $user
     * @param Adds $adds
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('adds.adds.create');
    }

    /**
     * Determine if the given user can update the given adds.
     *
     * @param UserPolicy $user
     * @param Adds $adds
     *
     * @return bool
     */
    public function update(UserPolicy $user, Adds $adds)
    {
        if ($user->canDo('adds.adds.edit') && $user->isAdmin()) {
            return true;
        }

        return $adds->user_id == user_id() && $adds->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given adds.
     *
     * @param UserPolicy $user
     * @param Adds $adds
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Adds $adds)
    {
        return $adds->user_id == user_id() && $adds->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given adds.
     *
     * @param UserPolicy $user
     * @param Adds $adds
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Adds $adds)
    {
        if ($user->canDo('adds.adds.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given adds.
     *
     * @param UserPolicy $user
     * @param Adds $adds
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Adds $adds)
    {
        if ($user->canDo('adds.adds.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
